package a2_withMultipleViews;

import java.awt.Canvas;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.event.MouseMotionListener;

import javax.swing.JComponent;

/**
 * Encapsulation of LineDrawView, taken from:
 * 
 * - Olsen Fig 2.5, p. 19 (called DrawView in this eg)
 * 
 * - Fig 3.18 p. 70
 * 
 * @author mb
 * 
 */
public class LineDrawView extends Canvas {
	private LineDrawModel myModel;

	public LineDrawView(LineDrawModel model) {
		this.myModel = model;
		LineDrawListener myListener = new MyLineDrawListener(this, myModel);
		// to listen for event dispatched from the model, install listener on
		// the model
		myModel.addListener(myListener);
		// to listen for mouse motion events, install listener as below
		this.addMouseMotionListener(myListener);
		// to listen for mouse events (which are different that *mouse motion*
		// events, install listener as below
		this.addMouseListener(myListener);
	}

	/*
	 * Paint when the AWT tells us to...
	 */
	public void paint(Graphics g) {
		Graphics2D g2 = (Graphics2D) g;
		for (int i = 0; i < myModel.getNumberOfLines(); i++) {
			Line theLine = myModel.getLine(i);
			g2.setStroke(theLine.getStroke());
			g2.setColor(theLine.getColour());
			g2.drawLine(theLine.getStartPoint().x, theLine.getStartPoint().y,
					theLine.getEndPoint().x, theLine.getEndPoint().y);
		}
	}

	public Dimension getPreferredSize() {
		return new Dimension(400, 200);
	}

}
